Installing ATLAS Rucio Clients — Rucio 0.3.8 documentation

# Installing ATLAS Rucio Clients

## Prerequisites

Rucio clients runs on Python 2.6, 2.7.

Platforms: Rucio should run on any Unix-like platform.

## Python Dependencies

Rucio clients need the following python modules:

    argparse==1.3.0 # Command-line parsing library
    argcomplete==0.8.8 # Bash tab completion for argparse
    kerberos==1.2.2 # Kerberos high-level interface
    requests==2.7.0 # Python HTTP for Humans
    requests-kerberos==0.7.0 # A Kerberos authentication handler for python-requests
    #  TODO: requests-cache==0.4.8  # Persistent cache for requests library
    urllib3==1.10.4 # HTTP library with thread-safe connection pooling and file post support
    wsgiref==0.1.2 # WSGI (PEP 333) Reference Library
    dogpile==0.2.2 # Caching API
    dogpile.core==0.4.1 # Caching API
    dogpile.cache==0.5.6 # Caching API plugins
    nose==1.3.6 # rucio test-server
    boto==2.38.0 # S3 boto protocol
    tabulate==0.7.5 # Pretty-print tabular data
    progressbar==2.3 # Text progress bar

All Dependencies are automatically installed with pip.

## Setup CERN AFS client on lxplus

CERN Quickstart:

- bash:

      $> source /afs/cern.ch/atlas/offline/external/GRID/ddm/rucio/testing/bin/activate

- csh:

      $> source /afs/cern.ch/atlas/offline/external/GRID/ddm/rucio/testing/bin/activate.csh

By default the RUCIO_ACCOUNT variable is set to the AFS username.

- To test rucio:

      $> rucio ping
      $> rucio whoami
      $> rucio-admin account list-identities $RUCIO_ACCOUNT

## Install via pip

When `pip` is available, the distribution can be downloaded from the Rucio PyPI server and installed in one step:

    $> pip install atlas-rucio-clients

This command will download the latest version of Rucio and install it to your system.

## Upgrade via pip

To upgrade via pip:

    $> pip install --upgrade rucio-clients

## Install via pip and virtualenv

To install the Rucio clients in an isolated `virtualenv` environment:

    $> cd /tmp
    $> curl -s https://raw.github.com/pypa/virtualenv/master/virtualenv.py | python2.6 - rucio # install virtual env
    $> source rucio/bin/activate
    $> pip install atlas-rucio-clients # install rucio-clients + atlas config
    $> export RUCIO_ACCOUNT=$USER
    $> source rucio/bin/activate
    $> rucio ping

## Installing using setup.py

Otherwise, you can install from the distribution using the `setup.py` script:

    $> python setup.py install